@@ -1,7 +1,7 @@
 import functools
 import os
-
-from snipper.legacy import indent, block_process
+from snipper.legacy import block_process
+from snipper.block_parsing import indent
 
 
 def run_o(lines, file, output):
@@ -11,7 +11,6 @@ def run_o(lines, file, output):
         l2 = []
         l2 += [id + "import sys", id + f"sys.stdout = open('{outf}', 'w')"]
         l2 += lines
-        # l2 += [indent(lines[-1]) + "sys.stdout.close()"]
         l2 += [indent(lines[-1]) + "sys.stdout = sys.__stdout__"]
         return l2, None
     try:
